==> github-automated-repos-1.3.0.tgz: package/hook/utils/_handleRepository.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { fetchGitHubAPI } from '../api/fetchGitHubAPI';
import { _handleBanner } from './_handleBanner';
/**
 * @param {string} usernameGitHub - Insert your username GitHub Ex.: https://github.com/USERNAME
 * @param {string} keyWordDeploy - Insert a keyword chosen by you. - This key is responsible for managing your projects on GitHub in topics field Ex.: https://github.com/DIGOARTHUR/github-automated-repos#--about-library-.
 * @param {React.Dispatch<React.SetStateAction<IGithubRepos[]>} setRepositoriesData  - Insert <useState> function to receive data from the GitHub API linked to the keyword. !! Don't forget to enter keywords in GitHub projects. !!
 * @param {React.Dispatch<React.SetStateAction<boolean>} setLoading  - Insert <useState> function to receive loading states.
 * @param {React.Dispatch<React.SetStateAction<string>} setError - Insert <useState> function to receive request error message
 */
// Função de busca
export const fetchRepositories = (usernameGitHub, keyWordDeploy) => __awaiter(void 0, void 0, void 0, function* () {
    const jsonData = yield fetchGitHubAPI(usernameGitHub);
    const datafilter = jsonData.filter((item) => item.topics.includes(keyWordDeploy));
    const repositories = yield Promise.all(datafilter.map((item) => __awaiter(void 0, void 0, void 0, function* () {
        const banner = yield _handleBanner(usernameGitHub, item.name);
        return {
            id: item.id,
            name: item.name,
            html_url: item.html_url,
            description: item.description,
            topics: item.topics,
            homepage: item.homepage,
            banner,
        };
    })));
    return repositories;
});
// Hook personalizado
export function _handleRepository(usernameGitHub, keyWordDeploy) {
}

==> github-automated-repos-1.3.1.tgz: package/hook/utils/_handleRepository.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { fetchGitHubAPI } from '../api/fetchGitHubAPI';
import { _handleBanner } from './_handleBanner';
/**
 * @param {string} usernameGitHub - Insert your GitHub username. See in your GitHub Ex.: https://github.com/USERNAME
 * @param {string} keyWordDeploy - Insert a keyword chosen by you. - This key is responsible for managing your projects on GitHub in topics field. See in : https://github.com/DIGOARTHUR/github-automated-repos.
 */
export const fetchRepositories = (usernameGitHub, keyWordDeploy) => __awaiter(void 0, void 0, void 0, function* () {
    const jsonData = yield fetchGitHubAPI(usernameGitHub);
    const datafilter = jsonData.filter((item) => item.topics.includes(keyWordDeploy));
    const repositories = yield Promise.all(datafilter.map((item) => __awaiter(void 0, void 0, void 0, function* () {
        const banner = yield _handleBanner(usernameGitHub, item.name);
        return {
            id: item.id,
            name: item.name,
            html_url: item.html_url,
            description: item.description,
            topics: item.topics,
            homepage: item.homepage,
            banner,
        };
    })));
    return repositories;
});
